==> theia-0.1.8.1-py3-none-any.whl: theia/aws/security/sg.py <==
import pulumi

from pulumi.output import Output

from typing import Optional, Mapping, List, Literal
from pydantic.dataclasses import dataclass, ConfigDict

from theia import ResourceOptions
from theia._registry import StackRegistry, GlobalTags
from theia.definitions import THEIA_VERSION, TRAFFIC_MAP
from theia.utils.errors import TheiaConfigurationError

from pulumi_aws import ec2


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class SecurityGroupSettings:
    sg_type: Literal["ingress", "egress"] = "egress"
    traffic_type: Literal[
        "All",
        "All TCP",
        "All UDP",
        "SSH",
        "SMTP",
        "DNS (UDP)",
        "DNS (TCP)",
        "HTTP",
        "HTTPS",
        "RDP",
        "Custom",
    ] = "All"
    from_port: int = None
    protocol: Literal["-1", "tcp", "udp", "icmp", "icmpv6"] = None
    to_port: int = None
    description: Optional[str] = None
    add_self: Optional[bool] = False
    cidr_blocks: Optional[List[str | Output[str]]] = None
    security_groups: Optional[List[str | Output[str]]] = None

    def __post_init__(self):
        if self.traffic_type != "Custom":
            self.from_port = TRAFFIC_MAP[self.traffic_type]["from"]
            self.to_port = TRAFFIC_MAP[self.traffic_type]["to"]
            self.protocol = TRAFFIC_MAP[self.traffic_type]["protocol"]
            if "All" in self.traffic_type:
                self.cidr_blocks = ["0.0.0.0/0"]
        else:
            if not self.to_port or not self.from_port or not self.protocol:
                raise TheiaConfigurationError(
                    "When giving Custom traffic_type, you need to specify to_port, from_port and protocol"
                )


class SecurityGroup:
    def __new__(
        cls,
        resource_name: str,
        vpc_id: Output[str] | str,
        settings: Optional[List[SecurityGroupSettings]] = [
            SecurityGroupSettings(cidr_blocks=["0.0.0.0/0"])
        ],
        description: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> ec2.SecurityGroup:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        ingress = []
        egress = []
        for arg in settings:
            if arg.sg_type == "egress":
                egress.append(
                    ec2.SecurityGroupEgressArgs(
                        from_port=arg.from_port,
                        protocol=arg.protocol,
                        to_port=arg.to_port,
                        cidr_blocks=arg.cidr_blocks,
                        description=arg.description,
                        self=arg.add_self,
                        security_groups=arg.security_groups,
                    )
                )
            elif arg.sg_type == "ingress":
                ingress.append(
                    ec2.SecurityGroupIngressArgs(
                        from_port=arg.from_port,
                        protocol=arg.protocol,
                        to_port=arg.to_port,
                        cidr_blocks=arg.cidr_blocks,
                        description=arg.description,
                        self=arg.add_self,
                        security_groups=arg.security_groups,
                    )
                )
        sg = ec2.SecurityGroup(
            vpc_id=vpc_id,
            resource_name=resource_name,
            name=resource_name,
            description=description,
            tags=merged_tags,
            egress=egress,
            ingress=ingress,
            opts=opts,
        )

        pulumi.export(f"security_group---{resource_name}", {"arn": sg.arn, "id": sg.id})

        return sg

    @staticmethod
    def import_(stack: str, resource_name: str) -> ec2.SecurityGroup:
        stack_ref = StackRegistry.get(stack_name=stack)
        sg = stack_ref.get_output(name=f"security_group---{resource_name}")
        return ec2.SecurityGroup.get(resource_name=resource_name, id=sg["id"])

==> theia-0.1.8.3-py3-none-any.whl: theia/aws/security/sg.py <==
import pulumi

from pulumi.output import Output

from typing import Optional, Mapping, List, Literal
from pydantic.dataclasses import dataclass, ConfigDict

from theia import ResourceOptions
from theia._registry import StackRegistry, GlobalTags
from theia.definitions import THEIA_VERSION, TRAFFIC_MAP
from theia.utils.errors import TheiaConfigurationError

from pulumi_aws import ec2


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class SecurityGroupSettings:
    sg_type: Literal["ingress", "egress"] = "egress"
    traffic_type: Literal[
        "All",
        "All TCP",
        "All UDP",
        "SSH",
        "SMTP",
        "DNS (UDP)",
        "DNS (TCP)",
        "HTTP",
        "HTTPS",
        "RDP",
        "Custom",
    ] = "All"
    from_port: int = None
    protocol: Literal["-1", "tcp", "udp", "icmp", "icmpv6"] = None
    to_port: int = None
    description: Optional[str] = None
    add_self: Optional[bool] = False
    cidr_blocks: Optional[List[str | Output[str]]] = None
    security_groups: Optional[List[str | Output[str]]] = None

    def __post_init__(self):
        if self.traffic_type != "Custom":
            self.from_port = TRAFFIC_MAP[self.traffic_type]["from"]
            self.to_port = TRAFFIC_MAP[self.traffic_type]["to"]
            self.protocol = TRAFFIC_MAP[self.traffic_type]["protocol"]
            if "All" in self.traffic_type and not len(self.cidr_blocks):
                self.cidr_blocks = ["0.0.0.0/0"]
        else:
            if not self.to_port or not self.from_port or not self.protocol:
                raise TheiaConfigurationError(
                    "When giving Custom traffic_type, you need to specify to_port, from_port and protocol"
                )


class SecurityGroup:
    def __new__(
        cls,
        resource_name: str,
        vpc_id: Output[str] | str,
        settings: Optional[List[SecurityGroupSettings]] = [
            SecurityGroupSettings(cidr_blocks=["0.0.0.0/0"])
        ],
        description: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> ec2.SecurityGroup:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        ingress = []
        egress = []
        for arg in settings:
            if arg.sg_type == "egress":
                egress.append(
                    ec2.SecurityGroupEgressArgs(
                        from_port=arg.from_port,
                        protocol=arg.protocol,
                        to_port=arg.to_port,
                        cidr_blocks=arg.cidr_blocks,
                        description=arg.description,
                        self=arg.add_self,
                        security_groups=arg.security_groups,
                    )
                )
            elif arg.sg_type == "ingress":
                ingress.append(
                    ec2.SecurityGroupIngressArgs(
                        from_port=arg.from_port,
                        protocol=arg.protocol,
                        to_port=arg.to_port,
                        cidr_blocks=arg.cidr_blocks,
                        description=arg.description,
                        self=arg.add_self,
                        security_groups=arg.security_groups,
                    )
                )
        sg = ec2.SecurityGroup(
            vpc_id=vpc_id,
            resource_name=resource_name,
            name=resource_name,
            description=description,
            tags=merged_tags,
            egress=egress,
            ingress=ingress,
            opts=opts,
        )

        pulumi.export(f"security_group---{resource_name}", {"arn": sg.arn, "id": sg.id})

        return sg

    @staticmethod
    def import_(stack: str, resource_name: str) -> ec2.SecurityGroup:
        stack_ref = StackRegistry.get(stack_name=stack)
        sg = stack_ref.get_output(name=f"security_group---{resource_name}")
        return ec2.SecurityGroup.get(resource_name=resource_name, id=sg["id"])
